@@ -5,11 +5,12 @@ SimpleIO: Common Python I/O interactions
 """
 
 import sys
+import time
 
 from diddiparser2.diddiscript_types import Floating, Integer, Text
-from diddiparser2.messages import run_error
+from diddiparser2.messages import run_error, show_warning
 
-DIDDISCRIPT_FUNCTIONS = ("program_exit", "print_text", "print_line", "store_input")
+DIDDISCRIPT_FUNCTIONS = ("program_exit", "print_text", "print_line", "store_input", "wait")
 
 
 def program_exit(msg):
@@ -24,14 +25,14 @@ def program_exit(msg):
     sys.exit(msg)
 
 
-def print_text(txt):
+def print_text(*txt):
     "Print something on the screen."
-    print(txt, end="")
+    print(*txt, end="")
 
 
-def print_line(txt):
+def print_line(*txt):
     "Print something, plus a newline."
-    print(txt)
+    print(*txt)
 
 
 def store_input(msg):
@@ -41,3 +42,18 @@ def store_input(msg):
     except KeyboardInterrupt:
         run_error("Input request was interrupted by user!")
     return Text(text)
+
+
+def warning(msg):
+    "Show a warning."
+    show_warning(str(msg))
+
+
+def wait(amount):
+    """
+    Wait for {amount} seconds of time.
+    Both floats and ints are accepted.
+    """
+    if not isinstance(amount, Floating) and not isinstance(amount, Integer):
+        run_error(f"Expected Floating or Integer types, but got type '{type(amount).__name__}'")
+    time.sleep(amount.value)
